==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/TemplateRepositoryFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link TemplateRepository}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class TemplateRepositoryFieldAttributes extends AbstractBeanAttributesDefinition{

    /** content (Database column: CONTENT) */
    static public AttributeDefinition content =
        new AttributeDefinition("content")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("TEMPLATE_REPOSITORY")
                .setDatabaseId("CONTENT")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("TEMPLATE_REPOSITORY")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** language (Database column: LANGUAGE) */
    static public AttributeDefinition language =
        new AttributeDefinition("language")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("TEMPLATE_REPOSITORY")
                .setDatabaseId("LANGUAGE")
                .setMandatory(true)
                .setMaxSize(2)
                .setType(String.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("TEMPLATE_REPOSITORY")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(300)
                .setType(String.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(content.getName(),content);
        map.put(id.getName(),id);
        map.put(language.getName(),language);
        map.put(name.getName(),name);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/TemplateRepositoryFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link TemplateRepository}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class TemplateRepositoryFieldAttributes extends AbstractBeanAttributesDefinition{

    /** content (Database column: CONTENT) */
    static public AttributeDefinition content =
        new AttributeDefinition("content")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("TEMPLATE_REPOSITORY")
                .setDatabaseId("CONTENT")
                .setMandatory(true)
                .setMaxSize(4000)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("TEMPLATE_REPOSITORY")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setType(Long.class);

    /** language (Database column: LANGUAGE) */
    static public AttributeDefinition language =
        new AttributeDefinition("language")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("TEMPLATE_REPOSITORY")
                .setDatabaseId("LANGUAGE")
                .setMandatory(true)
                .setMaxSize(2)
                .setType(String.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("TEMPLATE_REPOSITORY")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(300)
                .setType(String.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(content.getName(),content);
        map.put(id.getName(),id);
        map.put(language.getName(),language);
        map.put(name.getName(),name);

        return map;
    }
}
